<?php

namespace XenGenTr\XenOneCikanKonular\Repository;

use XF\Mvc\Entity\AbstractCollection;
use XF\Mvc\Entity\Repository;

class Onecikan extends Repository
{
	public function findOnecikan()
	{
		return $this->finder('XenGenTr\XenOneCikanKonular:Onecikan')
			->with('Thread', true)
			->order('onecikan_tarih', 'DESC');
	}
	
	public function fetchOnecikanByThread($thread)
	{
		return $this->finder('XenGenTr\XenOneCikanKonular:Onecikan')
			->where('thread_id', $thread->thread_id)
			->fetchOne();
	}
	
	public function parseOnecikanlar($onecikanlar, $trim = 0)
	{
		foreach ($onecikanlar AS &$onecikan)
		{
			$onecikan = $this->parseOnecikan($onecikan, $trim);
		}
		
		return $onecikanlar;
	}
	
	public function parseOnecikan($onecikan, $trim = 0)
	{

        $options = $this->options;
        $trim = \XF::options()->XenGenTr_OneCikanKonular_limit;


		if (empty($onecikan->onecikan_icerik))
		{
			$onecikan->onecikan_icerik = $onecikan->Thread->FirstPost->message;
		}
		
		$onecikan->onecikan_icerik = str_replace(["\r","\n"], ' ', $onecikan->onecikan_icerik);
		
		$formatter = \XF::app()->stringFormatter();
		$onecikan->onecikan_icerik = $formatter->snippetString($onecikan->onecikan_icerik, $trim, ['stripBbCode' => true]);
		
		return $onecikan;
	}
	
	public function setOnecikanFromUpload($thread, $upload)
	{
		$upload->requireImage();

		if (!$upload->isValid($errors))
		{
			throw new \XF\PrintableException(reset($errors));
		}
		
		$target = 'data://onecikan_konular/'.$thread->thread_id.'.jpg';
		$dimensions = \XF::options()->XenGenTr_OneCikanKonular_Boyutlari;
		$width = $dimensions['width'];
		$height = $dimensions['height'];
			
		try
		{
			$image = \XF::app()->imageManager->imageFromFile($upload->getTempFile());
			
			$ratio = $width / $height;
			$w = $image->getWidth();
			$h = $image->getHeight();
			
			if ($w / $h > $ratio)
			{
				$image->resizeTo($w * ($height / $h), $height);
			}
			else
			{
				$image->resizeTo($width, $h * ($width / $w));
			}

			$w = $image->getWidth();
			$h = $image->getHeight();
			$offWidth = ($w - $width) / 2;
			$offHeight = ($h - $height) / 2;

			$image->crop($width, $height, $offWidth, $offHeight);
			
			$tempFile = \XF\Util\File::getTempFile();
			if ($tempFile && $image->save($tempFile))
			{
				$output = $tempFile;
			}
			unset($image);
			
			\XF\Util\File::copyFileToAbstractedPath($output, $target);
		}
		catch (Exception $e)
		{
			throw new \XF\PrintableException(\XF::phrase('XenGenTr_OneCikanKonular_hata_olustu'));
		}
	}
}